# Components

The [`Page`][vizro.models.Page] model accepts the `components` argument, where you can enter any of the components
listed below to fill your dashboard with visuals.


<div class="grid cards" markdown>

- :octicons-graph-16:{ .lg .middle } __Graph__

    ---

    Use graphs to visualize your data with any Plotly chart.

    [:octicons-arrow-right-24: View User Guide](graph.md)

- :material-table-large:{ .lg .middle } __Table__

    ---

    Use tables to visualize your tabular data.

    [:octicons-arrow-right-24: View User Guide](table.md)

- :material-cards-outline:{ .lg .middle } __Card & button__

    ---

    Use cards and buttons to visualize text, navigate to different URLs or attach any [action](actions.md).

    [:octicons-arrow-right-24: View User Guide](card-button.md)

- :octicons-table-16:{ .lg .middle } __Container__

    ---

    Use containers to group your page components into sections and subsections.

    [:octicons-arrow-right-24: View User Guide](container.md)

- :material-tab-plus:{ .lg .middle } __Tabs__

    ---

    Use tabs to group your containers and navigate between them.

    [:octicons-arrow-right-24: View User Guide](tabs.md)

</div>
